@@ -22,14 +22,31 @@
 #include <sys/wait.h>
 #include <sys/time.h>
 
+#ifdef _AIX
+#  include <sys/select.h>
+#endif
+
+#ifdef _AIX
+#  include <sys/select.h>
+#endif
+#ifdef VMS
+#  include <sys/socket.h>     /* for fd_set */
+#endif
 #define IN_LIBIDENT_SRC
 #include "ident.h"
 
 
+/*
 int id_query __P4(ident_t *, id,
 		  int, lport,
 		  int, fport,
 		  struct timeval *, timeout)
+*/
+
+int    id_query __P((	ident_t *id,                 
+			int lport,                   
+			int fport,                   
+			__STRUCT_TIMEVAL_P timeout))
 {
 #ifdef SIGRETURNTYPE
     SIGRETURNTYPE (*old_sig)();
@@ -46,11 +63,12 @@ int id_query __P4(ident_t *, id,
     {
 	FD_ZERO(&ws);
 	FD_SET(id->fd, &ws);
-	
-	if ((res = select(FD_SETSIZE,
-			  (fd_set *)0, &ws,
-			  (fd_set *)0,
-			  timeout)) < 0)
+
+#ifdef __hpux
+	if ((res = select(FD_SETSIZE, (int *)0, (int *)&ws, (int *)0, timeout)) < 0)
+#else
+	if ((res = select(FD_SETSIZE, (fd_set *)0, &ws, (fd_set *)0, timeout)) < 0)
+#endif
 	    return -1;
 	
 	if (res == 0)
