@@ -1,3 +1,9 @@
+/*
+** support.c
+**
+** Author: Pr Emanuelsson <pell@lysator.liu.se>
+** Hacked by: Peter Eriksson <pen@lysator.liu.se>
+*/
 #include <stdio.h>
 #include <ctype.h>
 
@@ -12,18 +18,26 @@
 #include "ident.h"
 
 
-char *_id_strdup __P1(char *, str)
+char *id_strdup __P1(char *, str)
 {
     char *cp;
 
     cp = (char *) malloc(strlen(str)+1);
+    if (cp == NULL)
+    {
+#ifdef DEBUG
+	perror("libident: malloc");
+#endif
+        return NULL;
+    }
+
     strcpy(cp, str);
 
     return cp;
 }
 
 
-char *_id_strtok __P3(char *, cp,
+char *id_strtok __P3(char *, cp,
 		      char *, cs,
 		      char *, dc)
 {
